instrumenttools.Tuba
====================

.. abjad-lineage:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba

.. autoclass:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.Tuba.__repr__
   :noindex:
